# Disables freetype 1 and 2 bytecode interpreter.  Setting to 0 enables
# the bytecode interpreter in both freetype 1 and 2.
%define without_bytecode_interpreter	1

%define with_freetype1	1

%define ft1 freetype-pre1.4

Summary: A free and portable TrueType font rendering engine.
Name: freetype
Version: 2.1.4
Release: b1
License: BSD/GPL dual license
Group: System Environment/Libraries
URL: http://www.freetype.org
Source:  freetype-%{version}.tar.bz2
Source1: ftdocs-%{version}.tar.bz2
Source2: ft2demos-%{version}.tar.bz2
Source3: %{ft1}.tar.bz2

# Fix build of freetype-1.4 with gcc 3.3
Patch3: freetype-1.4-ac25.patch
Patch4: freetype-1.4-gcc33.patch
# Fix bug with non-format-0 hdmx tables
Patch5: freetype-2.1.4-freehdmx.patch
Patch20:  freetype-2.1.3-enable-ft2-bci.patch
Patch21:  freetype-1.4-disable-ft1-bci.patch

Buildroot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: automake14 autoconf libtool symlinks

BuildArchitectures: i586


%description
The FreeType engine is a free and portable TrueType font rendering
engine, developed to provide TrueType support for a variety of
platforms and environments. FreeType is a library which can open and
manages font files as well as efficiently load, hint and render
individual glyphs. FreeType is not a font server or a complete
text-rendering library.


%if %{with_freetype1}
%package utils
Summary: A collection of FreeType utilities.
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}

%description utils
The FreeType engine is a free and portable TrueType font rendering
engine, developed to provide TrueType support for a variety of
platforms and environments. FreeType is a library which can open and
manages font files as well as efficiently load, hint and render
individual glyphs. FreeType is not a font server or a complete
text-rendering library.
%endif

%package demos
Summary: A collection of FreeType demos.
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}

%description demos
The FreeType engine is a free and portable TrueType font rendering
engine, developed to provide TrueType support for a variety of
platforms and environments. FreeType is a library which can open and
manages font files as well as efficiently load, hint and render
individual glyphs. FreeType is not a font server or a complete
text-rendering library.


%package devel
Summary: FreeType development libraries and header files
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
The FreeType engine is a free and portable TrueType font rendering
engine, developed to provide TrueType support for a variety of
platforms and environments. FreeType is a library which can open and
manages font files as well as efficiently load, hint and render
individual glyphs. FreeType is not a font server or a complete
text-rendering library.


%prep
%setup -q -b 1 -a 2 -a 3

%patch5   -p1 -b .freehdmx

%if %{with_freetype1}
pushd %{ft1}
%patch3   -p1 -b .ac25
%patch4   -p1 -b .gcc33

%if %{without_bytecode_interpreter}
%patch21  -p1 -b .disable-ft1-bci
%endif
popd
%endif

%if ! %{without_bytecode_interpreter}
%patch20  -p0 -b .enable-ft2-bci
%endif

# Need to update libtool to get deplibs right for x86_64
pushd builds/unix
libtoolize --force
aclocal-1.4
autoconf
popd

pushd %{ft1}
libtoolize --force
aclocal-1.4
autoconf
popd

%build
# Build Freetype 2
{
  export CFLAGS="$RPM_OPT_FLAGS" CXXFLAGS="$RPM_OPT_FLAGS"
  %configure
  make %{?_smp_mflags}
}

%if %{with_freetype1}
# Build Freetype 1.4
{
  pushd %{ft1}
  %configure --disable-debug --enable-static --enable-shared \
             --with-locale-dir=%{_datadir}/locale
  make X11_LIB=/usr/X11R6/%{_lib}

  # Absolute symlinks in the debug output break debuginfo, 
  # so use 'symlinks' to relativize and shorten; takes
  # two passes because 'symlinks' is stupid.
  symlinks -r -c . > /dev/null
  symlinks -r -s -c . > /dev/null

  popd
}
%endif

# Build freetype 2 demos
{
  pushd ft2demos-%{version}
  make X11_LIB=/usr/X11R6/%{_lib} X11_PATH="/usr/X11R6" TOP_DIR=".."
  popd
}

%install
rm -rf $RPM_BUILD_ROOT


# Install Freetype 2
%makeinstall gnulocaledir=$RPM_BUILD_ROOT%{_datadir}/locale

%if %{with_freetype1}
# Install Freetype 1
{
  pushd %{ft1}
  %makeinstall gnulocaledir=$RPM_BUILD_ROOT%{_datadir}/locale
  libtool --finish $RPM_BUILD_ROOT%{_libdir}
  popd
}
%endif
%if %{with_freetype1}
mkdir -p $RPM_BUILD_ROOT/%{_includedir}/freetype1
mv $RPM_BUILD_ROOT/%{_includedir}/freetype $RPM_BUILD_ROOT/%{_includedir}/freetype1
%endif

# Install freetype 2 demos
{
  for ftdemo in ftdump ftlint ftmemchk ftmulti ftstring fttimer ftview ;do
      libtool install -m 755 ft2demos-%{version}/bin/$ftdemo $RPM_BUILD_ROOT/%{_bindir}
  done
}
%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%triggerpostun -- freetype < 2.0.5-3
{
  # ttmkfdir updated - as of 2.0.5-3, on upgrades we need xfs to regenerate
  # things to get the iso10646-1 encoding listed.
  for I in %{_datadir}/fonts/*/TrueType /usr/X11R6/lib/X11/fonts/TrueType; do
      [ -d $I ] && [ -f $I/fonts.scale ] && [ -f $I/fonts.dir ] && touch $I/fonts.scale
  done
  exit 0
}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root)
%{_libdir}/libfreetype.so.*
%doc ChangeLog README
%if %{with_freetype1}
# FIXME: This isn't getting created at build time for some reason.
%{_libdir}/libttf.so.*
%doc %{ft1}/README %{ft1}/announce docs
%endif

%if %{with_freetype1}
%files utils
%defattr(-,root,root)
# 2.0.4 version included in demos package now
#%{_bindir}/ftdump
# 2.0.4 version included in demos package now
#%{_bindir}/ftlint
%{_bindir}/fterror
%{_bindir}/ftmetric
%{_bindir}/ftsbit
%{_bindir}/ftstrpnm
%endif

%files demos
%defattr(-,root,root)
%{_bindir}/ftdump
%{_bindir}/ftlint
%{_bindir}/ftmemchk
%{_bindir}/ftmulti
%{_bindir}/ftstring
%{_bindir}/fttimer
%{_bindir}/ftview

%files devel
%defattr(-,root,root)
%if %{with_freetype1}
%dir %{_includedir}/freetype1
%{_includedir}/freetype1/*
%endif
%dir %{_includedir}/freetype2
%{_datadir}/aclocal/freetype2.m4
%{_includedir}/freetype2/*
%{_includedir}/*.h
%if %{with_freetype1}
%{_libdir}/libttf.a
%{_libdir}/libttf.la
# FIXME: This isn't getting created at build time for some reason.
%{_libdir}/libttf.so
%endif
%{_libdir}/libfreetype.a
%{_libdir}/libfreetype.la
%{_libdir}/libfreetype.so
%{_bindir}/freetype-config


%changelog
* Sat Jul 19 2003 Yuichiro Nakada <berry@po.yui.mine.nu>
- Create for Berry Linux
- from Rawhide
- freetype-2.1.4-4.0.src.rpm
